register_global_callback

Function register_global_callback 

pub fn register_global_callback<T: Config>(contract: T::AccountId)
Register a global ink! callback for an address.

This contract is used for each callback within the substrate system. It allows a user to set a default callback contract that will be triggered for any hook point unless a specific callback is set.

  • contract: The contract address to use as the endpoint for all callbacks.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::register_global_callback.