register_specific_callback

Function register_specific_callback 

pub fn register_specific_callback<T: Config>(
    contract: T::AccountId,
    id: Vec<u8>,
)
Register a specific ink! callback for an address.

Allows a user to set a callback for a specific hook point. This will take precedence over the global callback for the given hook point.

  • contract: Contract address to use as the endpoint for this specific callback.
  • id: Identifier for this registration.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::register_specific_callback.